summaryrefslogtreecommitdiffstats
path: root/nisautofs_wizard
diff options
context:
space:
mode:
authorAntoine Ginies <aginies@mandriva.com>2006-06-20 20:54:31 +0000
committerAntoine Ginies <aginies@mandriva.com>2006-06-20 20:54:31 +0000
commitef83c3384527da74e78aa47c017c96dd34a629b9 (patch)
treee94e7cbe89ae84a1f07939b43939bf641607bd46 /nisautofs_wizard
parentfa60acb6d2feb2b86924afff15d1124c01a70f7d (diff)
downloaddrakwizard-ef83c3384527da74e78aa47c017c96dd34a629b9.tar
drakwizard-ef83c3384527da74e78aa47c017c96dd34a629b9.tar.gz
drakwizard-ef83c3384527da74e78aa47c017c96dd34a629b9.tar.bz2
drakwizard-ef83c3384527da74e78aa47c017c96dd34a629b9.tar.xz
drakwizard-ef83c3384527da74e78aa47c017c96dd34a629b9.zip
fix fixed_val and fixed_list
Diffstat (limited to 'nisautofs_wizard')
-rw-r--r--nisautofs_wizard/Nisautofs.pm17
1 files changed, 8 insertions, 9 deletions
diff --git a/nisautofs_wizard/Nisautofs.pm b/nisautofs_wizard/Nisautofs.pm
index 52f27c2a..eb10d4ca 100644
--- a/nisautofs_wizard/Nisautofs.pm
+++ b/nisautofs_wizard/Nisautofs.pm
@@ -59,7 +59,6 @@ my $o = {
create_missing_directory => '',
},
needed_rpm => [ 'ypserv', 'ypbind', 'nfs-utils', 'yp-tools', 'nfs-utils-clients' ],
- defaultimage => "$ENV{__WIZ_HOME__}/nisautofs_wizard/images/nisautofs.png",
init => sub {
test_host_domain($HOST, $NISDOMAIN);
},
@@ -92,14 +91,14 @@ $o->{pages} = {
summaryserver => {
name => N("The wizard will set your NIS server with autofs map"),
data => [
- { label => N("NIS server:"), fixed_val => \$HOST },
- { label => N("Home NIS:"), fixed_val => \$o->{var}{HOMENIS} },
- { label => N("NIS domainname:"), fixed_val => \$o->{var}{NISDOMAIN} },
- { label => N("NIS directory:"), fixed_val => \$o->{var}{NIS_DIRMAKEFILE} },
-# { label => N("Network file:"), fixed_val => \$o->{var}{NETWORKFILE} },
-# { label => N("NFS exports:"), fixed_val => \$o->{var}{NFSEXPORTS} },
-# { label => N("Auto master:"), fixed_val => \$o->{var}{AUTOMASTER} },
-# { label => N("Auto home:"), fixed_val => \$o->{var}{AUTOHOME} },
+ { label => N("NIS server:"), val_ref => \$HOST },
+ { label => N("Home NIS:"), val_ref => \$o->{var}{HOMENIS} },
+ { label => N("NIS domainname:"), val_ref => \$o->{var}{NISDOMAIN} },
+ { label => N("NIS directory:"), val_ref => \$o->{var}{NIS_DIRMAKEFILE} },
+# { label => N("Network file:"), val_ref => \$o->{var}{NETWORKFILE} },
+# { label => N("NFS exports:"), val_ref => \$o->{var}{NFSEXPORTS} },
+# { label => N("Auto master:"), val_ref => \$o->{var}{AUTOMASTER} },
+# { label => N("Auto home:"), val_ref => \$o->{var}{AUTOHOME} },
],
post => \&do_it_server,
next => 'endserver',